function summodosd(vmecSurface::VmecSurface, init_zeta::Float64, init_theta::Float64, npt::Int64, x::Vector{Float64},
                   c2::Vector{Float64}, k_s::Vector{Float64}, bsuppar::Vector{Float64}, b2::Vector{Float64})

  lfail_balloon = false;
  #it appears that the lambdas are on the half-grid and iotas are on the full grid.  seems to be a bug
  #We'll just assume full grid
  s = vmecSurface.s
  zetacn  = init_zeta;
  zetang = zetacn .+ x;

  #-----------------------------------------
  #        Begin Fourier inversion
  #
  #
  # Aaron's version using PET
  #      Initialize for Fourier inversion
  bfield   = zeros(npt);
  bfields  = zeros(npt);
  bfieldth = zeros(npt);
  bfieldze = zeros(npt);
  rboo     = zeros(npt);
  rs       = zeros(npt);
  rth      = zeros(npt);
  rze      = zeros(npt);
  zs       = zeros(npt);
  zth      = zeros(npt);
  zze      = zeros(npt);
  lambdas  = zeros(npt);
  lambdaze = zeros(npt);
  lambdath = zeros(npt);
  bsupth   = zeros(npt);
  bsupze   = zeros(npt);
  thetang  = zeros(npt);
  vmecCoords = VmecCoordinates(vmecSurface.s, init_theta, init_zeta)
  pestCoords = PestFromVmec()(vmecCoords, vmecSurface)
  αpest = pestCoords.α
  ψpest = pestCoords.ψ
  for i in 1:length(zetang)
    ζ = zetang[i]
    #sign convention used in fortran code
    pestCoords  = PestCoordinates(ψpest, αpest, -1*ζ);
    vmecCoords  = VmecFromPest()(pestCoords,vmecSurface)

    thetang[i]  = vmecCoords.θ
    bfield[i]   = inverseTransform(vmecCoords, vmecSurface.bmn)
    bfields[i]  = inverseTransform(vmecCoords, vmecSurface.bmn, deriv=:ds)
    bfieldth[i] = inverseTransform(vmecCoords, vmecSurface.bmn, deriv=:dθ)
    bfieldze[i] = inverseTransform(vmecCoords, vmecSurface.bmn, deriv=:dζ)
    rboo[i]     = inverseTransform(vmecCoords, vmecSurface.rmn)
    rs[i]       = inverseTransform(vmecCoords, vmecSurface.rmn, deriv=:ds)
    rth[i]      = inverseTransform(vmecCoords, vmecSurface.rmn, deriv=:dθ)
    rze[i]      = inverseTransform(vmecCoords, vmecSurface.rmn, deriv=:dζ)
    zs[i]       = inverseTransform(vmecCoords, vmecSurface.zmn, deriv=:ds)
    zth[i]      = inverseTransform(vmecCoords, vmecSurface.zmn, deriv=:dθ)
    zze[i]      = inverseTransform(vmecCoords, vmecSurface.zmn, deriv=:dζ)
    lambdas[i]  = inverseTransform(vmecCoords, vmecSurface.λmn, deriv=:ds)
    lambdaze[i] = inverseTransform(vmecCoords, vmecSurface.λmn, deriv=:dζ)
    lambdath[i] = inverseTransform(vmecCoords, vmecSurface.λmn, deriv=:dθ)
    bsupth[i]   = inverseTransform(vmecCoords, vmecSurface.bsupumn)
    bsupze[i]   = inverseTransform(vmecCoords, vmecSurface.bsupvmn)
  end


  #   End Fourier inversion
  #-----------------------------------------

  #      auxiliary quantities

  rboo2 = rboo.^2;
  bfieldi = 1 ./ bfield;
  b2 .= bfield.^2;
  bfield2i = bfieldi.^2;

  #      VMEC lower metric elements (gᵢⱼ = ∇rᵢᵏ δₖₗ ∇rⱼˡ)
  gtssub = rth.*rs + zth.*zs;
  gstsub = gtssub;
  gzssub = rze.*rs + zze.*zs;
  gszsub = gzssub;
  gtzsub = rth.*rze + zth.*zze;
  gztsub = gtzsub;
  gttsub = (rth.^2) + (zth.^2);
  gsssub = (rs.^2) + (zs.^2);
  gzzsub = (rze.^2) + (zze.^2) + rboo2;

  #       VMEC jacobian (jacob2 = det(g))

  jacob2 = gsssub.*gttsub.*gzzsub +
           2*gstsub.*gtzsub.*gszsub -
           gttsub.*gszsub.^2 -
           gzzsub.*gstsub.^2 -
           gsssub.*gztsub.^2;
  rjac2i = 1 ./ jacob2;

  #      VMEC upper metric elements ( (g⁻¹)ⁱʲ )
  #      ... Why are we using Kramer's rule?
  gsssup = (gttsub.*gzzsub - gtzsub.*gztsub).*rjac2i;
  gttsup = (gsssub.*gzzsub - gszsub.*gzssub).*rjac2i;
  gzzsup = (gsssub.*gttsub - gstsub.*gtssub).*rjac2i;
  gstsup = (gztsub.*gzssub - gstsub.*gzzsub).*rjac2i;
  gtssup = gstsup;
  gszsup = (gtssub.*gtzsub - gttsub.*gzssub).*rjac2i;
  gzssup = gszsup;
  gtzsup = (gstsub.*gzssub - gsssub.*gztsub).*rjac2i;
  gztsup = gtzsup;

  #      covariant B-components (Bᵢ = gᵢⱼ bʲ)
  bsubs =  bsupze.*gszsub + bsupth.*gstsub;
  bsubth =  bsupze.*gtzsub + bsupth.*gttsub;
  bsubze =  bsupze.*gzzsub + bsupth.*gtzsub;

  #      VMEC covariant curvature components (κⁱ = μ₀∇pⁱ/B²  + ∇⟂|B|/|B|, ∇⟂|B| = ∇|B| - (B⋅∇|B|)B/|B|² )
  aux = (bsupze.*bfieldze + bsupth.*bfieldth).*bfield2i;
  μ0 = 4*π*1.0E-7
  cks_vmec = bfieldi.*(bfields + bfieldi.*vmecSurface.pres[2]*μ0 - bsubs.*aux);
  ckth_vmec = bfieldi.*(bfieldth - bsubth.*aux);
  # ckϕ_vmec = bfieldi.*(bfieldze - bsubze.*aux) (not needed for the upcoming pushforward)
  # println("ζ = $(zetang[1]), θ = $init_theta, cks_vmec = $cks_vmec, ckth_vmec = $ckth_vmec")

  #      normal curvature in (s,alpha,phi)-coordinates ( ∇S/kα = ∇α + q'θₖ∇ψ ( +∇λ b/c of VMEC nastiness))
  lam1 = 1 .+ lambdath;
  lam2 = - vmecSurface.iota[1] .+ lambdaze;
  lam3 = - vmecSurface.iota[2]*x .+ lambdas;
  k_s .= cks_vmec - ckth_vmec.*lam3 ./ lam1;
  # println("s ζ = $(zetang[1]), θ = $(thetang[1]), ∇S1 = $([lam3[1], lam1[1], lam2[1]])")

  #      normal vector squared ‖∇S/kα‖² (Equal to B²(1+Λ²)/‖∇ψ‖² )
  c2 .= gzzsup.*lam2.^2 + gttsup.*lam1.^2 +
        gsssup.*lam3.^2 + 2*lam2.*lam3.*gzssup +
        2*lam3.*lam1.*gtssup + 2*lam1.*lam2.*gztsup;

  #      Contravariant zeta-component of field going to B.grad (B^ζ = (∇α×∇ψ)⋅∇ζ = 1/J)
  bsuppar .= bsupze;

#  for i in 1:length(zetang)
#    println("comp: ",zetang[i]," ",thetang[i], " ",bfield[i], " ",bfields[i], " ",bfieldth[i],
#            " ",bfieldze[i]," ",rboo[i]," ",rs[i]," ",rth[i]," ",rze[i]," ",
#            zs[i]," ",zth[i]," ",zze[i]," ",lambdas[i]," ",lambdaze[i]," ",lambdath[i]," ",
#            bsupth[i]," ",bsupze[i]," ",cks_vmec[i]," ",aux[i]," ",c2[i])
#  end

  return lfail_balloon
end


# Gets the coefficients for interpolation by a BallooningCoefInterp object
# Returns c2_coef, κ_coef, and bsuppar
# To get c2 and ks (as the above function does), one uses
#    c2 = c2_coef[:, :, 1] + c2_coef[:, :, 2] * X + c2_coef[:, :, 3] * X^2
#    ks =  κ_coef[:, :, 1] +  κ_coef[:, :, 2] * X
# where X is the distance from the "origin" of the eigenvalue problem
function ballooning_coefficient_grid(vmecSurface::VmecSurface, ζvec::AbstractVector, αvec::AbstractVector)
  μ0 = 4*π*1.0E-7
  s = vmecSurface.s
  Nζ = length(ζvec);
  Nα = length(αvec);

  c2_coefs  = zeros(Nα, Nζ, 3);
  κ_coefs   = zeros(Nα, Nζ, 2);
  bsuppar   = zeros(Nα, Nζ)

  for iα = 1:length(αvec)
    vmecCoords = VmecCoordinates(vmecSurface.s, 0, 0)
    pestCoords = PestFromVmec()(vmecCoords, vmecSurface)
    αpest = αvec[iα]
    ψpest = pestCoords.ψ
    for iζ in 1:length(ζvec)
      ζ = ζvec[iζ]
      #sign convention used in fortran code
      pestCoords  = PestCoordinates(ψpest, αpest, -1*ζ);
      vmecCoords  = VmecFromPest()(pestCoords,vmecSurface)

      bmag     = inverseTransform(vmecCoords, vmecSurface.bmn)
      dbmag = zeros(3);
      dbmag[1] = inverseTransform(vmecCoords, vmecSurface.bmn, deriv=:ds)
      dbmag[2] = inverseTransform(vmecCoords, vmecSurface.bmn, deriv=:dθ)
      dbmag[3] = inverseTransform(vmecCoords, vmecSurface.bmn, deriv=:dζ)

      dr = zeros(3,3);
      dr[1, 1] = inverseTransform(vmecCoords, vmecSurface.rmn, deriv=:ds)
      dr[1, 2] = inverseTransform(vmecCoords, vmecSurface.rmn, deriv=:dθ)
      dr[1, 3] = inverseTransform(vmecCoords, vmecSurface.rmn, deriv=:dζ)
      dr[2, 1] = inverseTransform(vmecCoords, vmecSurface.zmn, deriv=:ds)
      dr[2, 2] = inverseTransform(vmecCoords, vmecSurface.zmn, deriv=:dθ)
      dr[2, 3] = inverseTransform(vmecCoords, vmecSurface.zmn, deriv=:dζ)
      dr[3, 3] = inverseTransform(vmecCoords, vmecSurface.rmn)

      dλ = zeros(3);
      dλ[1] = inverseTransform(vmecCoords, vmecSurface.λmn, deriv=:ds)
      dλ[2] = inverseTransform(vmecCoords, vmecSurface.λmn, deriv=:dθ)
      dλ[3] = inverseTransform(vmecCoords, vmecSurface.λmn, deriv=:dζ)

      bsup = zeros(3);
      bsup[2] = inverseTransform(vmecCoords, vmecSurface.bsupumn)
      bsup[3] = inverseTransform(vmecCoords, vmecSurface.bsupvmn)

      gsub = dr'*dr;
      bsub = gsub*bsup;

      ∇p = [vmecSurface.pres[2], 0.0, 0.0];
      κsub = μ0.*∇p./(bmag^2) + dbmag./bmag - ((dbmag'*bsup)/bmag^3).*bsub

      ι  = vmecSurface.iota[1];
      ιs = vmecSurface.iota[2];
      ∇S1 = dλ + [0, 1, -ι];
      # ∇S2 =      [0, 0, -ιs];

      gsup = inv(gsub);
      c2_coefs[iα, iζ, 1] =     ∇S1'  * gsup       * ∇S1   / (bmag^2);
      c2_coefs[iα, iζ, 2] = 2 * ∇S1'  * gsup[:, 1] * (-ιs) / (bmag^2);
      c2_coefs[iα, iζ, 3] =     (-ιs) * gsup[1, 1] * (-ιs) / (bmag^2);

#     k_s .= cks_vmec - ckth_vmec.*lam3 ./ lam1;
      κ_coefs[iα, iζ, 1] = κsub[1] - κsub[2] * ∇S1[1] / ∇S1[2]
      κ_coefs[iα, iζ, 2] =         - κsub[2] * (-ιs)  / ∇S1[2]

      bsuppar[iα, iζ] = bsup[3];
    end
  end

  return c2_coefs, κ_coefs, bsuppar
end
